@@ -1,13 +1,13 @@
-use actix_http::{body::Body as ActixBody, Response as ActixResponse, Error as ActixError};
+use actix_http::{body::Body as ActixBody, Error as ActixError, Response as ActixResponse};
 use actix_web::dev::ServiceResponse as ActixServiceResponse;
 
 use crate::asserter::status::{assert_status, assert_status_range};
 
-use super::super::AsserhttpStatus;
+use super::super::{AnyStatus, AsserhttpStatus};
 
 impl AsserhttpStatus<ActixResponse<ActixBody>> for ActixResponse<ActixBody> {
-    fn expect_status_eq(&mut self, status: u16) -> &mut Self {
-        assert_status(self.status().as_u16(), status);
+    fn expect_status_eq<S: Into<AnyStatus>>(&mut self, status: S) -> &mut Self {
+        assert_status(self.status().as_u16(), status.into().0);
         self
     }
 
@@ -18,7 +18,7 @@ impl AsserhttpStatus<ActixResponse<ActixBody>> for ActixResponse<ActixBody> {
 }
 
 impl AsserhttpStatus<ActixResponse<ActixBody>> for Result<ActixResponse<ActixBody>, ActixError> {
-    fn expect_status_eq(&mut self, status: u16) -> &mut ActixResponse<ActixBody> {
+    fn expect_status_eq<S: Into<AnyStatus>>(&mut self, status: S) -> &mut ActixResponse<ActixBody> {
         self.as_mut().unwrap().expect_status_eq(status)
     }
 
@@ -28,8 +28,8 @@ impl AsserhttpStatus<ActixResponse<ActixBody>> for Result<ActixResponse<ActixBod
 }
 
 impl AsserhttpStatus<ActixServiceResponse<ActixBody>> for ActixServiceResponse<ActixBody> {
-    fn expect_status_eq(&mut self, status: u16) -> &mut Self {
-        assert_status(self.status().as_u16(), status);
+    fn expect_status_eq<S: Into<AnyStatus>>(&mut self, status: S) -> &mut Self {
+        assert_status(self.status().as_u16(), status.into().0);
         self
     }
 
