@@ -3,13 +3,13 @@ use awc::error::SendRequestError as AwcError;
 
 use crate::asserter::status::{assert_status, assert_status_range};
 
-use super::super::AsserhttpStatus;
+use super::super::{AnyStatus, AsserhttpStatus};
 
 pub type AwcResponse = awc::ClientResponse<Decoder<Payload>>;
 
 impl AsserhttpStatus<AwcResponse> for AwcResponse {
-    fn expect_status_eq(&mut self, status: u16) -> &mut Self {
-        assert_status(self.status().as_u16(), status);
+    fn expect_status_eq<S: Into<AnyStatus>>(&mut self, status: S) -> &mut Self {
+        assert_status(self.status().as_u16(), status.into().0);
         self
     }
 
@@ -20,7 +20,7 @@ impl AsserhttpStatus<AwcResponse> for AwcResponse {
 }
 
 impl AsserhttpStatus<AwcResponse> for Result<AwcResponse, AwcError> {
-    fn expect_status_eq(&mut self, status: u16) -> &mut AwcResponse {
+    fn expect_status_eq<S: Into<AnyStatus>>(&mut self, status: S) -> &mut AwcResponse {
         self.as_mut().unwrap().expect_status_eq(status)
     }
 
