@@ -2,11 +2,11 @@ use surf::{Error as SurfError, Response as SurfResponse};
 
 use crate::asserter::status::{assert_status, assert_status_range};
 
-use super::super::AsserhttpStatus;
+use super::super::{AnyStatus, AsserhttpStatus};
 
 impl AsserhttpStatus<SurfResponse> for SurfResponse {
-    fn expect_status_eq(&mut self, status: u16) -> &mut Self {
-        assert_status(u16::from(self.status()), status);
+    fn expect_status_eq<S: Into<AnyStatus>>(&mut self, status: S) -> &mut Self {
+        assert_status(u16::from(self.status()), status.into().0);
         self
     }
 
@@ -17,7 +17,7 @@ impl AsserhttpStatus<SurfResponse> for SurfResponse {
 }
 
 impl AsserhttpStatus<SurfResponse> for Result<SurfResponse, SurfError> {
-    fn expect_status_eq(&mut self, status: u16) -> &mut SurfResponse {
+    fn expect_status_eq<S: Into<AnyStatus>>(&mut self, status: S) -> &mut SurfResponse {
         self.as_mut().unwrap().expect_status_eq(status)
     }
 
